# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/litecms/meeting/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Litecms\\Meeting\\": "packages/litecms/meeting/src",
            "Litecms\\Meeting\\Seeders\\": "packages/litecms/meeting/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Litecms\Meeting\Providers\MeetingServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Meeting'  => Litecms\Meeting\Facades\Meeting::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Litecms\\Meeting\\Seeders\\MeetingTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Litecms\Meeting\Providers\MeetingServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Litecms\Meeting\Providers\MeetingServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Litecms\Meeting\Providers\MeetingServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/meeting/{modulename}

**User**

    http://path-to-route-folder/user/meeting/{modulename}

**Public**

    http://path-to-route-folder/meetings


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/meeting/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/meeting/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/meeting/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/meeting/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/meeting/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/meeting/{modulename}/{slug}
    METHOD: GET