<?php

namespace Litecms\Meeting\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\Meeting\Models\Meeting;

class MeetingPolicy
{

    /**
     * Determine if the given user can view the meeting.
     *
     * @param UserPolicyInterface $authUser
     * @param Meeting $meeting
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Meeting $meeting)
    {
        if ($authUser->canDo('meeting.meeting.view') && $authUser->isAdmin()) {
            return true;
        }

        return $meeting->user_id == user_id() && $meeting->user_type == user_type();
    }

    /**
     * Determine if the given user can create a meeting.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('meeting.meeting.create');
    }

    /**
     * Determine if the given user can update the given meeting.
     *
     * @param UserPolicyInterface $authUser
     * @param Meeting $meeting
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Meeting $meeting)
    {
        if ($authUser->canDo('meeting.meeting.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $meeting->user_id == user_id() && $meeting->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given meeting.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Meeting $meeting)
    {
        return $meeting->user_id == user_id() && $meeting->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given meeting.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Meeting $meeting)
    {
        if ($authUser->canDo('meeting.meeting.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given meeting.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Meeting $meeting)
    {
        if ($authUser->canDo('meeting.meeting.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
